.. bookstore documentation master file, created by
   sphinx-quickstart on Mon Oct 22 20:40:04 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. mdinclude:: ../../README.md

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   contributing
   code_of_conduct
   releasing
   changelog


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
